Idkwhttph Package
Idkwhttph package is a multi use text styler and backend helper. It includes many built in functions to make it easier for you to do great things.

What can it do?
• Center text in the middle of the screen
• Typewriter effect
• Backup and load database files
• Make code into characters
• Setting the title of a project
• Clearing the screen of text
• Clearing a line of text
• ANSI text styling
• Printing layers
• //Option menu//
• Crashing
• Syncing databases
• Enter to continue
• //Signup and login presets//

Functions:
printInMiddle(text, columns)
• Print in middle prints text in the center of your output console.

write(string, speed)
• Adds a type writer effect when printing a string, you can change the speed of which it types out the text.

create_backup()
• Makes a backup of your database and stores it into a JSON.

load_backup()
• Loads your backup from the JSON file and puts into your database.

save_backup()
• When you create a backup you can save it so if something happens it is perfectly fine.

sync_backup()
• Syncs your backup to the platform you are using.

code_to_chars(code)
• Turns your code into characters.

set_title(title)
• Adds a title to the project you are working on.

clear_screen()
• Clears the console of text, the result will make the console empty.

clear_line()
• Clears the latest line of text in the console.

Cursor(object)
• Move the cursor in the specified position of: UP, DOWN, FORWARD, BACK, and can get the position (POS).

Fore(color)
• Contains multiple colors to style your text such as: BLACK, RED, GREEN, YELLOW, BLUE, MAGENTA, CYAN, WHITE, LIGHTBLACK_EX, LIGHTRED_EX, LIGHTGREEN_EX, LIGHTYELLOW_EX, LIGHTBLUE_EX, LIGHTMAGENTA_EX, LIGHTCYAN_EX, LIGHTWHITE_EX, and RESET.

Back(color)
• Contains multiple colors to style the background of text such as: BLACK, RED, GREEN, YELLOW, BLUE, MAGENTA, CYAN, WHITE, LIGHTBLACK_EX, LIGHTRED_EX, LIGHTGREEN_EX, LIGHTYELLOW_EX, LIGHTBLUE_EX, LIGHTMAGENTA_EX, LIGHTCYAN_EX, LIGHTWHITE_EX, and RESET.

Style(style)
• Adds effect to your text such as: BRIGHT, DIM, NORMAL, and RESET_ALL.

print_layer()
• Prints string in layers.

options(prompt, menu, title, bold)
• Adds a select menu with specified inputs from the user to customize the menu.

crash()
• Crashes the Python code, causing the console to stop outputting.

Code Presets:
Sign_In()
• Adds a signup feature to your code, it stores and saves the credentials safely.

Log_In()
• Pairs with the sign_in function to allow people to access things when logged in.